MAP Application Parameter tag constants.
Constants
- CHARSET
- Character set (0x01 = UTF-8).
- FILTER_
MESSAGE_ TYPE - Bitmask — see
FilterMessageType. - FOLDER_
LISTING_ SIZE - Response-only: total folder count available.
- MESSAGES_
LISTING_ SIZE - Response-only: total message count available (MAP 1.4 wire tag 0x12).
- NEW_
MESSAGE - Response-only: 1 if unread messages exist.
- NOTIFICATION_
STATUS - 1 = enable MNS event reports, 0 = disable.
- RETRY
- If set, retry delivery on transient failure.
- STATUS_
INDICATOR - Selects which status property to update in
SetMessageStatus. - STATUS_
VALUE - The new value for the selected status property in
SetMessageStatus. - TRANSPARENT
- If set, message is not copied to the sent folder.