MNS OBEX server โ accepts connections from the remote device and yields MAP event reports.
Structs
- MnsServer
- MNS OBEX server. Receives a connection from the remote device on the MNS RFCOMM channel,
performs the OBEX handshake, and yields MAP event reports via
next_event.